@@ -1,5 +1,5 @@
-def foo(x, y):
-    """A dummy string.
+def add(x, y):
+    """Add two numbers.
 
     :param int x: x value.
     :param int y: y value.
