@@ -1,5 +1,5 @@
-def foo(x: int, y: int):  # [differing-type-doc]
-    """A dummy string.
+def add(x: int, y: int):  # [differing-type-doc]
+    """Add two numbers.
 
     :param int xy: x value.
     :param str y: y value.
