@@ -4,5 +4,10 @@ def find_the_treasure(clues):
             return True
     return False
 
-treasure_hunt = ["Dead Man's Chest", "X marks the spot", "The treasure is buried near the palm tree"]
+
+treasure_hunt = [
+    "Dead Man's Chest",
+    "X marks the spot",
+    "The treasure is buried near the palm tree",
+]
 find_the_treasure(treasure_hunt)
