@@ -1,74 +1,37 @@
-# Copyright (c) 2006-2014 LOGILAB S.A. (Paris, FRANCE) <contact@logilab.fr>
-# Copyright (c) 2012-2015 Google, Inc.
-# Copyright (c) 2013 moxian <aleftmail@inbox.ru>
-# Copyright (c) 2014-2020 Claudiu Popa <pcmanticore@gmail.com>
-# Copyright (c) 2014 frost-nzcr4 <frost.nzcr4@jagmort.com>
-# Copyright (c) 2014 Brett Cannon <brett@python.org>
-# Copyright (c) 2014 Michal Nowikowski <godfryd@gmail.com>
-# Copyright (c) 2014 Arun Persaud <arun@nubati.net>
-# Copyright (c) 2015 Mike Frysinger <vapier@gentoo.org>
-# Copyright (c) 2015 Fabio Natali <me@fabionatali.com>
-# Copyright (c) 2015 Harut <yes@harutune.name>
-# Copyright (c) 2015 Mihai Balint <balint.mihai@gmail.com>
-# Copyright (c) 2015 Pavel Roskin <proski@gnu.org>
-# Copyright (c) 2015 Ionel Cristian Maries <contact@ionelmc.ro>
-# Copyright (c) 2016 Petr Pulc <petrpulc@gmail.com>
-# Copyright (c) 2016 Moises Lopez <moylop260@vauxoo.com>
-# Copyright (c) 2016 Ashley Whetter <ashley@awhetter.co.uk>
-# Copyright (c) 2017, 2019-2020 hippo91 <guillaume.peillex@gmail.com>
-# Copyright (c) 2017-2018 Bryce Guinta <bryce.paul.guinta@gmail.com>
-# Copyright (c) 2017 Krzysztof Czapla <k.czapla68@gmail.com>
-# Copyright (c) 2017 Łukasz Rogalski <rogalski.91@gmail.com>
-# Copyright (c) 2017 James M. Allen <james.m.allen@gmail.com>
-# Copyright (c) 2017 vinnyrose <vinnyrose@users.noreply.github.com>
-# Copyright (c) 2018-2021 Pierre Sassoulas <pierre.sassoulas@gmail.com>
-# Copyright (c) 2018, 2020 Bryce Guinta <bryce.guinta@protonmail.com>
-# Copyright (c) 2018, 2020 Anthony Sottile <asottile@umich.edu>
-# Copyright (c) 2018 Lucas Cimon <lucas.cimon@gmail.com>
-# Copyright (c) 2018 Michael Hudson-Doyle <michael.hudson@canonical.com>
-# Copyright (c) 2018 Natalie Serebryakova <natalie.serebryakova@Natalies-MacBook-Pro.local>
-# Copyright (c) 2018 ssolanki <sushobhitsolanki@gmail.com>
-# Copyright (c) 2018 Marcus Näslund <naslundx@gmail.com>
-# Copyright (c) 2018 Mike Frysinger <vapier@gmail.com>
-# Copyright (c) 2018 Fureigh <rhys.fureigh@gsa.gov>
-# Copyright (c) 2018 Andreas Freimuth <andreas.freimuth@united-bits.de>
-# Copyright (c) 2018 Jakub Wilk <jwilk@jwilk.net>
-# Copyright (c) 2019 Nick Drozd <nicholasdrozd@gmail.com>
-# Copyright (c) 2019 Hugo van Kemenade <hugovk@users.noreply.github.com>
-# Copyright (c) 2020 Raphael Gaschignard <raphael@rtpg.co>
-# Copyright (c) 2021 Marc Mueller <30130371+cdce8p@users.noreply.github.com>
-
 # Licensed under the GPL: https://www.gnu.org/licenses/old-licenses/gpl-2.0.html
-# For details: https://github.com/PyCQA/pylint/blob/master/LICENSE
+# For details: https://github.com/pylint-dev/pylint/blob/main/LICENSE
+# Copyright (c) https://github.com/pylint-dev/pylint/blob/main/CONTRIBUTORS.txt
 
 """Python code format's checker.
 
-By default try to follow Guido's style guide :
+By default, try to follow Guido's style guide :
 
 https://www.python.org/doc/essays/styleguide/
 
 Some parts of the process_token method is based from The Tab Nanny std module.
 """
 
+from __future__ import annotations
+
 import tokenize
-from functools import reduce  # pylint: disable=redefined-builtin
-from typing import List
+from functools import reduce
+from re import Match
+from typing import TYPE_CHECKING, Literal
 
 from astroid import nodes
 
-from pylint.checkers import BaseTokenChecker
-from pylint.checkers.utils import (
-    check_messages,
-    is_overload_stub,
-    is_protocol_class,
-    node_frame_class,
-)
+from pylint.checkers import BaseRawFileChecker, BaseTokenChecker
+from pylint.checkers.utils import only_required_for_messages
 from pylint.constants import WarningScope
-from pylint.interfaces import IAstroidChecker, IRawChecker, ITokenChecker
+from pylint.interfaces import HIGH
+from pylint.typing import MessageDefinitionTuple
 from pylint.utils.pragma_parser import OPTION_PO, PragmaParserError, parse_pragma
 
-_ASYNC_TOKEN = "async"
-_KEYWORD_TOKENS = [
+if TYPE_CHECKING:
+    from pylint.lint import PyLinter
+
+
+_KEYWORD_TOKENS = {
     "assert",
     "del",
     "elif",
@@ -82,42 +45,13 @@ _KEYWORD_TOKENS = [
     "while",
     "yield",
     "with",
-]
+    "=",
+    ":=",
+}
+_JUNK_TOKENS = {tokenize.COMMENT, tokenize.NL}
 
-_SPACED_OPERATORS = [
-    "==",
-    "<",
-    ">",
-    "!=",
-    "<>",
-    "<=",
-    ">=",
-    "+=",
-    "-=",
-    "*=",
-    "**=",
-    "/=",
-    "//=",
-    "&=",
-    "|=",
-    "^=",
-    "%=",
-    ">>=",
-    "<<=",
-]
-_OPENING_BRACKETS = ["(", "[", "{"]
-_CLOSING_BRACKETS = [")", "]", "}"]
-_TAB_LENGTH = 8
 
-_EOL = frozenset([tokenize.NEWLINE, tokenize.NL, tokenize.COMMENT])
-_JUNK_TOKENS = (tokenize.COMMENT, tokenize.NL)
-
-# Whitespace checking policy constants
-_MUST = 0
-_MUST_NOT = 1
-_IGNORE = 2
-
-MSGS = {
+MSGS: dict[str, MessageDefinitionTuple] = {
     "C0301": (
         "Line too long (%s/%s)",
         "line-too-long",
@@ -180,63 +114,45 @@ MSGS = {
 }
 
 
-def _last_token_on_line_is(tokens, line_end, token):
-    return (
-        line_end > 0
-        and tokens.token(line_end - 1) == token
-        or line_end > 1
+def _last_token_on_line_is(tokens: TokenWrapper, line_end: int, token: str) -> bool:
+    return (line_end > 0 and tokens.token(line_end - 1) == token) or (
+        line_end > 1
         and tokens.token(line_end - 2) == token
         and tokens.type(line_end - 1) == tokenize.COMMENT
     )
 
 
-# The contexts for hanging indents.
-# A hanging indented dictionary value after :
-HANGING_DICT_VALUE = "dict-value"
-# Hanging indentation in an expression.
-HANGING = "hanging"
-# Hanging indentation in a block header.
-HANGING_BLOCK = "hanging-block"
-# Continued indentation inside an expression.
-CONTINUED = "continued"
-# Continued indentation in a block header.
-CONTINUED_BLOCK = "continued-block"
-
-SINGLE_LINE = "single"
-WITH_BODY = "multi"
-
-
 class TokenWrapper:
     """A wrapper for readable access to token information."""
 
-    def __init__(self, tokens):
+    def __init__(self, tokens: list[tokenize.TokenInfo]) -> None:
         self._tokens = tokens
 
-    def token(self, idx):
+    def token(self, idx: int) -> str:
         return self._tokens[idx][1]
 
-    def type(self, idx):
+    def type(self, idx: int) -> int:
         return self._tokens[idx][0]
 
-    def start_line(self, idx):
+    def start_line(self, idx: int) -> int:
         return self._tokens[idx][2][0]
 
-    def start_col(self, idx):
+    def start_col(self, idx: int) -> int:
         return self._tokens[idx][2][1]
 
-    def line(self, idx):
+    def line(self, idx: int) -> str:
         return self._tokens[idx][4]
 
 
-class FormatChecker(BaseTokenChecker):
-    """checks for :
+class FormatChecker(BaseTokenChecker, BaseRawFileChecker):
+    """Formatting checker.
+
+    Checks for :
     * unauthorized constructions
     * strict indentation
     * line length
     """
 
-    __implements__ = (ITokenChecker, IAstroidChecker, IRawChecker)
-
     # configuration section name
     name = "format"
     # messages
@@ -250,7 +166,11 @@ class FormatChecker(BaseTokenChecker):
                 "default": 100,
                 "type": "int",
                 "metavar": "<int>",
-                "help": "Maximum number of characters on a single line.",
+                "help": (
+                    "Maximum number of characters on a single line. "
+                    "Pylint's default of 100 is based on PEP 8's guidance that teams "
+                    "may choose line lengths up to 99 characters."
+                ),
             },
         ),
         (
@@ -269,7 +189,7 @@ class FormatChecker(BaseTokenChecker):
             {
                 "default": False,
                 "type": "yn",
-                "metavar": "<y_or_n>",
+                "metavar": "<y or n>",
                 "help": (
                     "Allow the body of an if to be on the same "
                     "line as the test if there is no else."
@@ -281,7 +201,7 @@ class FormatChecker(BaseTokenChecker):
             {
                 "default": False,
                 "type": "yn",
-                "metavar": "<y_or_n>",
+                "metavar": "<y or n>",
                 "help": (
                     "Allow the body of a class to be on the same "
                     "line as the declaration if body contains "
@@ -333,14 +253,13 @@ class FormatChecker(BaseTokenChecker):
         ),
     )
 
-    def __init__(self, linter=None):
-        BaseTokenChecker.__init__(self, linter)
-        self._lines = None
-        self._visited_lines = None
-        self._bracket_stack = [None]
+    def __init__(self, linter: PyLinter) -> None:
+        super().__init__(linter)
+        self._lines: dict[int, str] = {}
+        self._visited_lines: dict[int, Literal[1, 2]] = {}
 
-    def new_line(self, tokens, line_end, line_start):
-        """a new line has been encountered, process it if necessary"""
+    def new_line(self, tokens: TokenWrapper, line_end: int, line_start: int) -> None:
+        """A new line has been encountered, process it if necessary."""
         if _last_token_on_line_is(tokens, line_end, ";"):
             self.add_message("unnecessary-semicolon", line=tokens.start_line(line_end))
 
@@ -348,32 +267,39 @@ class FormatChecker(BaseTokenChecker):
         line = tokens.line(line_start)
         if tokens.type(line_start) not in _JUNK_TOKENS:
             self._lines[line_num] = line.split("\n")[0]
-        self.check_lines(line, line_num)
+        self.check_lines(tokens, line_start, line, line_num)
 
-    def process_module(self, _module):
+    def process_module(self, node: nodes.Module) -> None:
         pass
 
+    # pylint: disable-next = too-many-return-statements, too-many-branches
     def _check_keyword_parentheses(
-        self, tokens: List[tokenize.TokenInfo], start: int
+        self, tokens: list[tokenize.TokenInfo], start: int
     ) -> None:
         """Check that there are not unnecessary parentheses after a keyword.
 
         Parens are unnecessary if there is exactly one balanced outer pair on a
-        line, and it is followed by a colon, and contains no commas (i.e. is not a
-        tuple).
+        line and contains no commas (i.e. is not a tuple).
 
         Args:
-        tokens: list of Tokens; the entire list of Tokens.
-        start: int; the position of the keyword in the token list.
+        tokens: The entire list of Tokens.
+        start: The position of the keyword in the token list.
         """
         # If the next token is not a paren, we're fine.
-        if self._bracket_stack[-1] == ":" and tokens[start].string == "for":
-            self._bracket_stack.pop()
         if tokens[start + 1].string != "(":
             return
+        if (
+            tokens[start].string == "not"
+            and start > 0
+            and tokens[start - 1].string == "is"
+        ):
+            # If this is part of an `is not` expression, we have a binary operator
+            # so the parentheses are not necessarily redundant.
+            return
         found_and_or = False
         contains_walrus_operator = False
         walrus_operator_depth = 0
+        contains_double_parens = 0
         depth = 0
         keyword_token = str(tokens[start].string)
         line_num = tokens[start].start[0]
@@ -393,78 +319,79 @@ class FormatChecker(BaseTokenChecker):
                 walrus_operator_depth = depth
             if token.string == "(":
                 depth += 1
+                if tokens[i + 1].string == "(":
+                    contains_double_parens = 1
             elif token.string == ")":
                 depth -= 1
                 if depth:
+                    if contains_double_parens and tokens[i + 1].string == ")":
+                        # For walrus operators in `if (not)` conditions and comprehensions
+                        if keyword_token in {"in", "if", "not"}:
+                            continue
+                        return
+                    contains_double_parens -= 1
                     continue
                 # ')' can't happen after if (foo), since it would be a syntax error.
-                if tokens[i + 1].string in (":", ")", "]", "}", "in") or tokens[
+                if tokens[i + 1].string in {":", ")", "]", "}", "in"} or tokens[
                     i + 1
-                ].type in (tokenize.NEWLINE, tokenize.ENDMARKER, tokenize.COMMENT):
-                    # The empty tuple () is always accepted.
+                ].type in {tokenize.NEWLINE, tokenize.ENDMARKER, tokenize.COMMENT}:
                     if contains_walrus_operator and walrus_operator_depth - 1 == depth:
-                        # Reset variable for possible following expressions
-                        contains_walrus_operator = False
-                        continue
+                        return
+                    # The empty tuple () is always accepted.
                     if i == start + 2:
                         return
-                    if keyword_token == "not":
-                        if not found_and_or:
-                            self.add_message(
-                                "superfluous-parens", line=line_num, args=keyword_token
-                            )
-                    elif keyword_token in ("return", "yield"):
-                        self.add_message(
-                            "superfluous-parens", line=line_num, args=keyword_token
-                        )
-                    elif not found_and_or:
-                        self.add_message(
-                            "superfluous-parens", line=line_num, args=keyword_token
-                        )
+                    if found_and_or:
+                        return
+                    if keyword_token == "in":
+                        # This special case was added in https://github.com/pylint-dev/pylint/pull/4948
+                        # but it could be removed in the future. Avoid churn for now.
+                        return
+                    self.add_message(
+                        "superfluous-parens", line=line_num, args=keyword_token
+                    )
                 return
             elif depth == 1:
-                # This is a tuple, which is always acceptable.
-                if token[1] == ",":
-                    return
-                # 'and' and 'or' are the only boolean operators with lower precedence
-                # than 'not', so parens are only required when they are found.
-                if token[1] in ("and", "or"):
-                    found_and_or = True
-                # A yield inside an expression must always be in parentheses,
-                # quit early without error.
-                elif token[1] == "yield":
-                    return
-                # A generator expression always has a 'for' token in it, and
-                # the 'for' token is only legal inside parens when it is in a
-                # generator expression.  The parens are necessary here, so bail
-                # without an error.
-                elif token[1] == "for":
-                    return
+                match token[1]:
+                    case ",":
+                        # This is a tuple, which is always acceptable.
+                        return
+                    case "and" | "or":
+                        # 'and' and 'or' are the only boolean operators with lower precedence
+                        # than 'not', so parens are only required when they are found.
+                        found_and_or = True
+                    case "yield":
+                        # A yield inside an expression must always be in parentheses,
+                        # quit early without error.
+                        return
+                    case "for":
+                        # A generator expression always has a 'for' token in it, and
+                        # the 'for' token is only legal inside parens when it is in a
+                        # generator expression.  The parens are necessary here, so bail
+                        # without an error.
+                        return
+                    case "else":
+                        # A generator expression can have an 'else' token in it.
+                        # We check the rest of the tokens to see if any problems occur after
+                        # the 'else'.
+                        if "(" in (i.string for i in tokens[i:]):
+                            self._check_keyword_parentheses(tokens[i:], 0)
+                        return
 
-    def _prepare_token_dispatcher(self):
-        dispatch = {}
-        for tokens, handler in [(_KEYWORD_TOKENS, self._check_keyword_parentheses)]:
-            for token in tokens:
-                dispatch[token] = handler
-        return dispatch
+    def process_tokens(self, tokens: list[tokenize.TokenInfo]) -> None:
+        """Process tokens and search for:
 
-    def process_tokens(self, tokens):
-        """process tokens and search for :
-
-        _ too long lines (i.e. longer than <max_chars>)
-        _ optionally bad construct (if given, bad_construct must be a compiled
+        - too long lines (i.e. longer than <max_chars>)
+        - optionally bad construct (if given, bad_construct must be a compiled
           regular expression).
         """
-        self._bracket_stack = [None]
         indents = [0]
         check_equal = False
         line_num = 0
         self._lines = {}
         self._visited_lines = {}
-        token_handlers = self._prepare_token_dispatcher()
-        self._last_line_ending = None
+        self._last_line_ending: str | None = None
         last_blank_line_num = 0
-        for idx, (tok_type, token, start, _, line) in enumerate(tokens):
+        for idx, (tok_type, string, start, _, line) in enumerate(tokens):
             if start[0] != line_num:
                 line_num = start[0]
                 # A tokenizer oddity: if an indented line contains a multi-line
@@ -475,66 +402,65 @@ class FormatChecker(BaseTokenChecker):
                 else:
                     self.new_line(TokenWrapper(tokens), idx - 1, idx)
 
-            if tok_type == tokenize.NEWLINE:
-                # a program statement, or ENDMARKER, will eventually follow,
-                # after some (possibly empty) run of tokens of the form
-                #     (NL | COMMENT)* (INDENT | DEDENT+)?
-                # If an INDENT appears, setting check_equal is wrong, and will
-                # be undone when we see the INDENT.
-                check_equal = True
-                self._check_line_ending(token, line_num)
-            elif tok_type == tokenize.INDENT:
-                check_equal = False
-                self.check_indent_level(token, indents[-1] + 1, line_num)
-                indents.append(indents[-1] + 1)
-            elif tok_type == tokenize.DEDENT:
-                # there's nothing we need to check here!  what's important is
-                # that when the run of DEDENTs ends, the indentation of the
-                # program statement (or ENDMARKER) that triggered the run is
-                # equal to what's left at the top of the indents stack
-                check_equal = True
-                if len(indents) > 1:
-                    del indents[-1]
-            elif tok_type == tokenize.NL:
-                if not line.strip("\r\n"):
-                    last_blank_line_num = line_num
-            elif tok_type not in (tokenize.COMMENT, tokenize.ENCODING):
-                # This is the first concrete token following a NEWLINE, so it
-                # must be the first token of the next program statement, or an
-                # ENDMARKER; the "line" argument exposes the leading whitespace
-                # for this statement; in the case of ENDMARKER, line is an empty
-                # string, so will properly match the empty string with which the
-                # "indents" stack was seeded
-                if check_equal:
+            match tok_type:
+                case tokenize.NEWLINE:
+                    # a program statement, or ENDMARKER, will eventually follow,
+                    # after some (possibly empty) run of tokens of the form
+                    #     (NL | COMMENT)* (INDENT | DEDENT+)?
+                    # If an INDENT appears, setting check_equal is wrong, and will
+                    # be undone when we see the INDENT.
+                    check_equal = True
+                    self._check_line_ending(string, line_num)
+                case tokenize.INDENT:
                     check_equal = False
-                    self.check_indent_level(line, indents[-1], line_num)
+                    self.check_indent_level(string, indents[-1] + 1, line_num)
+                    indents.append(indents[-1] + 1)
+                case tokenize.DEDENT:
+                    # there's nothing we need to check here!  what's important is
+                    # that when the run of DEDENTs ends, the indentation of the
+                    # program statement (or ENDMARKER) that triggered the run is
+                    # equal to what's left at the top of the indents stack
+                    check_equal = True
+                    if len(indents) > 1:
+                        del indents[-1]
+                case tokenize.NL:
+                    if not line.strip("\r\n"):
+                        last_blank_line_num = line_num
+                case tokenize.COMMENT | tokenize.ENCODING:
+                    pass
+                case _:
+                    # This is the first concrete token following a NEWLINE, so it
+                    # must be the first token of the next program statement, or an
+                    # ENDMARKER; the "line" argument exposes the leading white-space
+                    # for this statement; in the case of ENDMARKER, line is an empty
+                    # string, so will properly match the empty string with which the
+                    # "indents" stack was seeded
+                    if check_equal:
+                        check_equal = False
+                        self.check_indent_level(line, indents[-1], line_num)
 
-            if tok_type == tokenize.NUMBER and token.endswith("l"):
+            if tok_type == tokenize.NUMBER and string.endswith("l"):
                 self.add_message("lowercase-l-suffix", line=line_num)
 
-            try:
-                handler = token_handlers[token]
-            except KeyError:
-                pass
-            else:
-                handler(tokens, idx)
+            if string in _KEYWORD_TOKENS:
+                self._check_keyword_parentheses(tokens, idx)
 
         line_num -= 1  # to be ok with "wc -l"
-        if line_num > self.config.max_module_lines:
+        if line_num > self.linter.config.max_module_lines:
             # Get the line where the too-many-lines (or its message id)
             # was disabled or default to 1.
             message_definition = self.linter.msgs_store.get_message_definitions(
                 "too-many-lines"
             )[0]
             names = (message_definition.msgid, "too-many-lines")
-            line = next(
+            lineno = next(
                 filter(None, (self.linter._pragma_lineno.get(name) for name in names)),
                 1,
             )
             self.add_message(
                 "too-many-lines",
-                args=(line_num, self.config.max_module_lines),
-                line=line,
+                args=(line_num, self.linter.config.max_module_lines),
+                line=lineno,
             )
 
         # See if there are any trailing lines.  Do not complain about empty
@@ -542,7 +468,7 @@ class FormatChecker(BaseTokenChecker):
         if line_num == last_blank_line_num and line_num > 0:
             self.add_message("trailing-newlines", line=line_num)
 
-    def _check_line_ending(self, line_ending, line_num):
+    def _check_line_ending(self, line_ending: str, line_num: int) -> None:
         # check if line endings are mixed
         if self._last_line_ending is not None:
             # line_ending == "" indicates a synthetic newline added at
@@ -554,7 +480,7 @@ class FormatChecker(BaseTokenChecker):
         self._last_line_ending = line_ending
 
         # check if line ending is as expected
-        expected = self.config.expected_line_ending_format
+        expected = self.linter.config.expected_line_ending_format
         if expected:
             # reduce multiple \n\n\n\n to one \n
             line_ending = reduce(lambda x, y: x + y if x != y else x, line_ending, "")
@@ -566,9 +492,9 @@ class FormatChecker(BaseTokenChecker):
                     line=line_num,
                 )
 
-    @check_messages("multiple-statements")
-    def visit_default(self, node):
-        """check the node line number and check it if not yet done"""
+    @only_required_for_messages("multiple-statements")
+    def visit_default(self, node: nodes.NodeNG) -> None:
+        """Check the node line number and check it if not yet done."""
         if not node.is_statement:
             return
         if not node.root().pure_python:
@@ -576,14 +502,12 @@ class FormatChecker(BaseTokenChecker):
         prev_sibl = node.previous_sibling()
         if prev_sibl is not None:
             prev_line = prev_sibl.fromlineno
-        # The line on which a finally: occurs in a try/finally
-        # is not directly represented in the AST. We infer it
-        # by taking the last line of the body and adding 1, which
-        # should be the line of finally:
-        elif (
-            isinstance(node.parent, nodes.TryFinally) and node in node.parent.finalbody
-        ):
-            prev_line = node.parent.body[0].tolineno + 1
+        elif isinstance(
+            node.parent, nodes.Try
+        ) and self._is_first_node_in_else_finally_body(node, node.parent):
+            prev_line = self._infer_else_finally_line_number(node, node.parent)
+        elif isinstance(node.parent, nodes.Module):
+            prev_line = 0
         else:
             prev_line = node.parent.statement().fromlineno
         line = node.fromlineno
@@ -598,80 +522,88 @@ class FormatChecker(BaseTokenChecker):
         except AttributeError:
             tolineno = node.tolineno
         assert tolineno, node
-        lines = []
-        for line in range(line, tolineno + 1):
+        lines: list[str] = []
+        for line in range(line, tolineno + 1):  # noqa: B020
             self._visited_lines[line] = 1
             try:
                 lines.append(self._lines[line].rstrip())
             except KeyError:
                 lines.append("")
 
-    def _check_multi_statement_line(self, node, line):
-        """Check for lines containing multiple statements."""
-        # Do not warn about multiple nested context managers
-        # in with statements.
-        if isinstance(node, nodes.With):
-            return
-        # For try... except... finally..., the two nodes
-        # appear to be on the same line due to how the AST is built.
-        if isinstance(node, nodes.TryExcept) and isinstance(
-            node.parent, nodes.TryFinally
-        ):
-            return
-        if (
-            isinstance(node.parent, nodes.If)
-            and not node.parent.orelse
-            and self.config.single_line_if_stmt
-        ):
-            return
-        if (
-            isinstance(node.parent, nodes.ClassDef)
-            and len(node.parent.body) == 1
-            and self.config.single_line_class_stmt
-        ):
-            return
+    def _is_first_node_in_else_finally_body(
+        self, node: nodes.NodeNG, parent: nodes.Try
+    ) -> bool:
+        if parent.orelse and node == parent.orelse[0]:
+            return True
+        if parent.finalbody and node == parent.finalbody[0]:
+            return True
+        return False
 
-        # Function overloads that use ``Ellipsis`` are exempted.
-        if isinstance(node, nodes.Expr) and (
-            isinstance(node.value, nodes.Ellipsis)
-            or (isinstance(node.value, nodes.Const) and node.value.value is Ellipsis)
-        ):
-            frame = node.frame()
-            if is_overload_stub(frame) or is_protocol_class(node_frame_class(frame)):
+    def _infer_else_finally_line_number(
+        self, node: nodes.NodeNG, parent: nodes.Try
+    ) -> int:
+        last_line_of_prev_block = 0
+        if node in parent.finalbody and parent.orelse:
+            last_line_of_prev_block = parent.orelse[-1].tolineno
+        elif parent.handlers and parent.handlers[-1].body:
+            last_line_of_prev_block = parent.handlers[-1].body[-1].tolineno
+        elif parent.body:
+            last_line_of_prev_block = parent.body[-1].tolineno
+
+        return last_line_of_prev_block + 1 if last_line_of_prev_block else 0
+
+    def _check_multi_statement_line(self, node: nodes.NodeNG, line: int) -> None:
+        """Check for lines containing multiple statements."""
+        match node:
+            case nodes.With():
+                # Do not warn about multiple nested context managers in with statements.
+                return
+            case nodes.NodeNG(
+                parent=nodes.If(orelse=[])
+            ) if self.linter.config.single_line_if_stmt:
+                return
+            case nodes.NodeNG(
+                parent=nodes.ClassDef(body=[_])
+            ) if self.linter.config.single_line_class_stmt:
+                return
+            case nodes.Expr(
+                parent=nodes.FunctionDef() | nodes.ClassDef(),
+                value=nodes.Const(value=value),
+            ) if (
+                value is Ellipsis
+            ):
+                # Functions stubs and class with ``Ellipsis`` as body are exempted.
                 return
 
-        self.add_message("multiple-statements", node=node)
+        self.add_message("multiple-statements", node=node, confidence=HIGH)
         self._visited_lines[line] = 2
 
-    def check_line_ending(self, line: str, i: int) -> None:
-        """
-        Check that the final newline is not missing and that there is no trailing whitespace.
-        """
-        if not line.endswith("\n"):
-            self.add_message("missing-final-newline", line=i)
-            return
+    def check_trailing_whitespace_ending(self, line: str, i: int) -> None:
+        """Check that there is no trailing white-space."""
         # exclude \f (formfeed) from the rstrip
         stripped_line = line.rstrip("\t\n\r\v ")
         if line[len(stripped_line) :] not in ("\n", "\r\n"):
             self.add_message(
-                "trailing-whitespace", line=i, col_offset=len(stripped_line)
+                "trailing-whitespace",
+                line=i,
+                col_offset=len(stripped_line),
+                confidence=HIGH,
             )
 
-    def check_line_length(self, line: str, i: int) -> None:
-        """
-        Check that the line length is less than the authorized value
-        """
-        max_chars = self.config.max_line_length
-        ignore_long_line = self.config.ignore_long_lines
+    def check_line_length(self, line: str, i: int, checker_off: bool) -> None:
+        """Check that the line length is less than the authorized value."""
+        max_chars = self.linter.config.max_line_length
+        ignore_long_line = self.linter.config.ignore_long_lines
         line = line.rstrip()
         if len(line) > max_chars and not ignore_long_line.search(line):
-            self.add_message("line-too-long", line=i, args=(len(line), max_chars))
+            if checker_off:
+                self.linter.add_ignored_message("line-too-long", i)
+            else:
+                self.add_message("line-too-long", line=i, args=(len(line), max_chars))
 
     @staticmethod
-    def remove_pylint_option_from_lines(options_pattern_obj) -> str:
-        """
-        Remove the `# pylint ...` pattern from lines
-        """
+    def remove_pylint_option_from_lines(options_pattern_obj: Match[str]) -> str:
+        """Remove the `# pylint ...` pattern from lines."""
         lines = options_pattern_obj.string
         purged_lines = (
             lines[: options_pattern_obj.start(1)].rstrip()
@@ -680,10 +612,8 @@ class FormatChecker(BaseTokenChecker):
         return purged_lines
 
     @staticmethod
-    def is_line_length_check_activated(pylint_pattern_match_object) -> bool:
-        """
-        Return true if the line length check is activated
-        """
+    def is_line_length_check_activated(pylint_pattern_match_object: Match[str]) -> bool:
+        """Return True if the line length check is activated."""
         try:
             for pragma in parse_pragma(pylint_pattern_match_object.group(2)):
                 if pragma.action == "disable" and "line-too-long" in pragma.messages:
@@ -694,15 +624,13 @@ class FormatChecker(BaseTokenChecker):
         return True
 
     @staticmethod
-    def specific_splitlines(lines: str) -> List[str]:
-        """
-        Split lines according to universal newlines except those in a specific sets
+    def specific_splitlines(lines: str) -> list[str]:
+        """Split lines according to universal newlines except those in a specific
+        sets.
         """
         unsplit_ends = {
-            "\v",
-            "\x0b",
-            "\f",
-            "\x0c",
+            "\x0b",  # synonym of \v
+            "\x0c",  # synonym of \f
             "\x1c",
             "\x1d",
             "\x1e",
@@ -710,7 +638,7 @@ class FormatChecker(BaseTokenChecker):
             "\u2028",
             "\u2029",
         }
-        res = []
+        res: list[str] = []
         buffer = ""
         for atomic_line in lines.splitlines(True):
             if atomic_line[-1] not in unsplit_ends:
@@ -720,12 +648,15 @@ class FormatChecker(BaseTokenChecker):
                 buffer += atomic_line
         return res
 
-    def check_lines(self, lines: str, lineno: int) -> None:
-        """
-        Check lines have :
-            - a final newline
-            - no trailing whitespace
-            - less than a maximum number of characters
+    def check_lines(
+        self, tokens: TokenWrapper, line_start: int, lines: str, lineno: int
+    ) -> None:
+        """Check given lines for potential messages.
+
+        Check if lines have:
+        - a final newline
+        - no trailing white-space
+        - less than a maximum number of characters
         """
         # we're first going to do a rough check whether any lines in this set
         # go over the line limit. If none of them do, then we don't need to
@@ -735,22 +666,25 @@ class FormatChecker(BaseTokenChecker):
         # we'll also handle the line ending check here to avoid double-iteration
         # unless the line lengths are suspect
 
-        max_chars = self.config.max_line_length
+        max_chars = self.linter.config.max_line_length
 
         split_lines = self.specific_splitlines(lines)
 
         for offset, line in enumerate(split_lines):
-            self.check_line_ending(line, lineno + offset)
+            if not line.endswith("\n"):
+                self.add_message("missing-final-newline", line=lineno + offset)
+                continue
+            # We don't test for trailing whitespaces in strings
+            # See https://github.com/pylint-dev/pylint/issues/6936
+            # and https://github.com/pylint-dev/pylint/issues/3822
+            if tokens.type(line_start) != tokenize.STRING:
+                self.check_trailing_whitespace_ending(line, lineno + offset)
 
-        # hold onto the initial lineno for later
-        potential_line_length_warning = False
-        for offset, line in enumerate(split_lines):
-            # this check is purposefully simple and doesn't rstrip
-            # since this is running on every line you're checking it's
-            # advantageous to avoid doing a lot of work
-            if len(line) > max_chars:
-                potential_line_length_warning = True
-                break
+        # This check is purposefully simple and doesn't rstrip since this is running
+        # on every line you're checking it's advantageous to avoid doing a lot of work
+        potential_line_length_warning = any(
+            len(line) > max_chars for line in split_lines
+        )
 
         # if there were no lines passing the max_chars config, we don't bother
         # running the full line check (as we've met an even more strict condition)
@@ -759,20 +693,20 @@ class FormatChecker(BaseTokenChecker):
 
         # Line length check may be deactivated through `pylint: disable` comment
         mobj = OPTION_PO.search(lines)
+        checker_off = False
         if mobj:
             if not self.is_line_length_check_activated(mobj):
-                # the line length check is deactivated, we can stop here
-                return
+                checker_off = True
             # The 'pylint: disable whatever' should not be taken into account for line length count
             lines = self.remove_pylint_option_from_lines(mobj)
 
         # here we re-run specific_splitlines since we have filtered out pylint options above
         for offset, line in enumerate(self.specific_splitlines(lines)):
-            self.check_line_length(line, lineno + offset)
+            self.check_line_length(line, lineno + offset, checker_off)
 
-    def check_indent_level(self, string, expected, line_num):
-        """return the indent level of the string"""
-        indent = self.config.indent_string
+    def check_indent_level(self, string: str, expected: int, line_num: int) -> None:
+        """Return the indent level of the string."""
+        indent = self.linter.config.indent_string
         if indent == "\\t":  # \t is not interpreted in the configuration file
             indent = "\t"
         level = 0
@@ -795,6 +729,5 @@ class FormatChecker(BaseTokenChecker):
             )
 
 
-def register(linter):
-    """required method to auto register this checker"""
+def register(linter: PyLinter) -> None:
     linter.register_checker(FormatChecker(linter))
