@@ -13,9 +13,11 @@ import sys
 from collections import defaultdict
 from collections.abc import ItemsView, Sequence
 from functools import cached_property
-from typing import TYPE_CHECKING, Any, Union
+from typing import TYPE_CHECKING, Any
 
 import astroid
+import astroid.modutils
+import isort
 from astroid import nodes
 from astroid.nodes._base_nodes import ImportNode
 
@@ -34,7 +36,6 @@ from pylint.graph import DotBackend, get_cycles
 from pylint.interfaces import HIGH
 from pylint.reporters.ureports.nodes import Paragraph, Section, VerbatimText
 from pylint.typing import MessageDefinitionTuple
-from pylint.utils import IsortDriver
 from pylint.utils.linterstats import LinterStats
 
 if TYPE_CHECKING:
@@ -43,11 +44,10 @@ if TYPE_CHECKING:
 
 # The dictionary with Any should actually be a _ImportTree again
 # but mypy doesn't support recursive types yet
-_ImportTree = dict[str, Union[list[dict[str, Any]], list[str]]]
+_ImportTree = dict[str, list[dict[str, Any]] | list[str]]
 
 DEPRECATED_MODULES = {
     (0, 0, 0): {"tkinter.tix", "fpectl"},
-    (3, 2, 0): {"optparse"},
     (3, 3, 0): {"xml.etree.cElementTree"},
     (3, 4, 0): {"imp"},
     (3, 5, 0): {"formatter"},
@@ -79,7 +79,6 @@ DEPRECATED_MODULES = {
         "uu",
         "xdrlib",
     },
-    (3, 13, 0): {"getopt"},
 }
 
 
@@ -323,6 +322,7 @@ DEFAULT_KNOWN_THIRD_PARTY = ("enchant",)
 DEFAULT_PREFERRED_MODULES = ()
 
 
+# pylint: disable-next = too-many-instance-attributes
 class ImportsChecker(DeprecatedMixin, BaseChecker):
     """BaseChecker for import statements.
 
@@ -459,6 +459,15 @@ class ImportsChecker(DeprecatedMixin, BaseChecker):
         )
         self._excluded_edges: defaultdict[str, set[str]] = defaultdict(set)
 
+        self._isort_config = isort.Config(
+            # There is no typo here. EXTRA_standard_library is
+            # what most users want. The option has been named
+            # KNOWN_standard_library for ages in pylint, and we
+            # don't want to break compatibility.
+            extra_standard_library=linter.config.known_standard_library,
+            known_third_party=linter.config.known_third_party,
+        )
+
     def open(self) -> None:
         """Called before visiting project (i.e set of modules)."""
         self.linter.stats.dependencies = {}
@@ -747,7 +756,6 @@ class ImportsChecker(DeprecatedMixin, BaseChecker):
         imports = [import_node for (import_node, _) in imports]
         return any(astroid.are_exclusive(import_node, node) for import_node in imports)
 
-    # pylint: disable = too-many-statements
     def _check_imports_order(self, _module_node: nodes.Module) -> tuple[
         list[tuple[ImportNode, str]],
         list[tuple[ImportNode, str]],
@@ -766,7 +774,6 @@ class ImportsChecker(DeprecatedMixin, BaseChecker):
         third_party_not_ignored: list[tuple[ImportNode, str]] = []
         first_party_not_ignored: list[tuple[ImportNode, str]] = []
         local_not_ignored: list[tuple[ImportNode, str]] = []
-        isort_driver = IsortDriver(self.linter.config)
         for node, modname in self._imports_stack:
             if modname.startswith("."):
                 package = "." + modname.split(".")[1]
@@ -776,84 +783,85 @@ class ImportsChecker(DeprecatedMixin, BaseChecker):
             ignore_for_import_order = not self.linter.is_message_enabled(
                 "wrong-import-order", node.fromlineno
             )
-            import_category = isort_driver.place_module(package)
+            import_category = isort.place_module(package, config=self._isort_config)
             node_and_package_import = (node, package)
 
-            if import_category in {"FUTURE", "STDLIB"}:
-                std_imports.append(node_and_package_import)
-                wrong_import = (
-                    third_party_not_ignored
-                    or first_party_not_ignored
-                    or local_not_ignored
-                )
-                if self._is_fallback_import(node, wrong_import):
-                    continue
-                if wrong_import and not nested:
-                    self.add_message(
-                        "wrong-import-order",
-                        node=node,
-                        args=(  ## TODO - this isn't right for multiple on the same line...
-                            f'standard import "{self._get_full_import_name((node, package))}"',
-                            self._get_out_of_order_string(
-                                third_party_not_ignored,
-                                first_party_not_ignored,
-                                local_not_ignored,
-                            ),
-                        ),
+            match import_category:
+                case "FUTURE" | "STDLIB":
+                    std_imports.append(node_and_package_import)
+                    wrong_import = (
+                        third_party_not_ignored
+                        or first_party_not_ignored
+                        or local_not_ignored
                     )
-            elif import_category == "THIRDPARTY":
-                third_party_imports.append(node_and_package_import)
-                external_imports.append(node_and_package_import)
-                if not nested:
-                    if not ignore_for_import_order:
-                        third_party_not_ignored.append(node_and_package_import)
-                    else:
-                        self.linter.add_ignored_message(
-                            "wrong-import-order", node.fromlineno, node
-                        )
-                wrong_import = first_party_not_ignored or local_not_ignored
-                if wrong_import and not nested:
-                    self.add_message(
-                        "wrong-import-order",
-                        node=node,
-                        args=(
-                            f'third party import "{self._get_full_import_name((node, package))}"',
-                            self._get_out_of_order_string(
-                                None, first_party_not_ignored, local_not_ignored
+                    if self._is_fallback_import(node, wrong_import):
+                        continue
+                    if wrong_import and not nested:
+                        self.add_message(
+                            "wrong-import-order",
+                            node=node,
+                            args=(  ## TODO - this isn't right for multiple on the same line...
+                                f'standard import "{self._get_full_import_name((node, package))}"',
+                                self._get_out_of_order_string(
+                                    third_party_not_ignored,
+                                    first_party_not_ignored,
+                                    local_not_ignored,
+                                ),
                             ),
-                        ),
-                    )
-            elif import_category == "FIRSTPARTY":
-                first_party_imports.append(node_and_package_import)
-                external_imports.append(node_and_package_import)
-                if not nested:
-                    if not ignore_for_import_order:
-                        first_party_not_ignored.append(node_and_package_import)
-                    else:
-                        self.linter.add_ignored_message(
-                            "wrong-import-order", node.fromlineno, node
                         )
-                wrong_import = local_not_ignored
-                if wrong_import and not nested:
-                    self.add_message(
-                        "wrong-import-order",
-                        node=node,
-                        args=(
-                            f'first party import "{self._get_full_import_name((node, package))}"',
-                            self._get_out_of_order_string(
-                                None, None, local_not_ignored
+                case "THIRDPARTY":
+                    third_party_imports.append(node_and_package_import)
+                    external_imports.append(node_and_package_import)
+                    if not nested:
+                        if not ignore_for_import_order:
+                            third_party_not_ignored.append(node_and_package_import)
+                        else:
+                            self.linter.add_ignored_message(
+                                "wrong-import-order", node.fromlineno, node
+                            )
+                    wrong_import = first_party_not_ignored or local_not_ignored
+                    if wrong_import and not nested:
+                        self.add_message(
+                            "wrong-import-order",
+                            node=node,
+                            args=(
+                                f'third party import "{self._get_full_import_name((node, package))}"',
+                                self._get_out_of_order_string(
+                                    None, first_party_not_ignored, local_not_ignored
+                                ),
                             ),
-                        ),
-                    )
-            elif import_category == "LOCALFOLDER":
-                local_imports.append((node, package))
-                if not nested:
-                    if not ignore_for_import_order:
-                        local_not_ignored.append((node, package))
-                    else:
-                        self.linter.add_ignored_message(
-                            "wrong-import-order", node.fromlineno, node
                         )
+                case "FIRSTPARTY":
+                    first_party_imports.append(node_and_package_import)
+                    external_imports.append(node_and_package_import)
+                    if not nested:
+                        if not ignore_for_import_order:
+                            first_party_not_ignored.append(node_and_package_import)
+                        else:
+                            self.linter.add_ignored_message(
+                                "wrong-import-order", node.fromlineno, node
+                            )
+                    wrong_import = local_not_ignored
+                    if wrong_import and not nested:
+                        self.add_message(
+                            "wrong-import-order",
+                            node=node,
+                            args=(
+                                f'first party import "{self._get_full_import_name((node, package))}"',
+                                self._get_out_of_order_string(
+                                    None, None, local_not_ignored
+                                ),
+                            ),
+                        )
+                case "LOCALFOLDER":
+                    local_imports.append((node, package))
+                    if not nested:
+                        if not ignore_for_import_order:
+                            local_not_ignored.append((node, package))
+                        else:
+                            self.linter.add_ignored_message(
+                                "wrong-import-order", node.fromlineno, node
+                            )
         return std_imports, external_imports, local_imports
 
     def _get_out_of_order_string(
@@ -1082,7 +1090,7 @@ class ImportsChecker(DeprecatedMixin, BaseChecker):
         """Check if the module has a preferred replacement."""
         mod_compare = [mod_path]
         # build a comparison list of possible names using importfrom
-        if isinstance(node, astroid.nodes.node_classes.ImportFrom):
+        if isinstance(node, nodes.ImportFrom):
             mod_compare = [f"{node.modname}.{name[0]}" for name in node.names]
 
         # find whether there are matches with the import vs preferred_modules keys
@@ -1172,10 +1180,13 @@ class ImportsChecker(DeprecatedMixin, BaseChecker):
     ) -> None:
         """Write dependencies as a dot (graphviz) file."""
         dep_info = self.linter.stats.dependencies
-        if not dep_info or not (
-            self.linter.config.import_graph
-            or self.linter.config.ext_import_graph
-            or self.linter.config.int_import_graph
+        if not (
+            dep_info
+            and (
+                self.linter.config.import_graph
+                or self.linter.config.ext_import_graph
+                or self.linter.config.int_import_graph
+            )
         ):
             raise EmptyReportError()
         filename = self.linter.config.import_graph
@@ -1195,7 +1206,7 @@ class ImportsChecker(DeprecatedMixin, BaseChecker):
             for importer in importers:
                 package = self._module_pkg.get(importer, importer)
                 is_inside = importee.startswith(package)
-                if is_inside and internal or not is_inside and not internal:
+                if (is_inside and internal) or (not is_inside and not internal):
                     graph[importee].add(importer)
         return graph
 
