@@ -1,25 +1,21 @@
 # Licensed under the GPL: https://www.gnu.org/licenses/old-licenses/gpl-2.0.html
-# For details: https://github.com/PyCQA/pylint/blob/main/LICENSE
-# Copyright (c) https://github.com/PyCQA/pylint/blob/main/CONTRIBUTORS.txt
+# For details: https://github.com/pylint-dev/pylint/blob/main/LICENSE
+# Copyright (c) https://github.com/pylint-dev/pylint/blob/main/CONTRIBUTORS.txt
 
-import sys
-from typing import TYPE_CHECKING, List, Optional, Set, Tuple, Type, Union, cast
+from __future__ import annotations
+
+import difflib
+from typing import TYPE_CHECKING, TypeGuard, cast
 
 from astroid import nodes
 
 from pylint.checkers import BaseChecker, utils
-from pylint.checkers.utils import check_messages, safe_infer
-from pylint.interfaces import IAstroidChecker
-from pylint.utils.utils import get_global_option
+from pylint.checkers.utils import only_required_for_messages, safe_infer
+from pylint.interfaces import INFERENCE
 
 if TYPE_CHECKING:
     from pylint.lint import PyLinter
 
-if sys.version_info >= (3, 10):
-    from typing import TypeGuard
-else:
-    from typing_extensions import TypeGuard
-
 
 class CodeStyleChecker(BaseChecker):
     """Checkers that can improve code consistency.
@@ -37,10 +33,7 @@ class CodeStyleChecker(BaseChecker):
     3. Everything else should go into another extension
     """
 
-    __implements__ = (IAstroidChecker,)
-
     name = "code_style"
-    priority = -1
     msgs = {
         "R6101": (
             "Consider using namedtuple or dataclass for dictionary values",
@@ -61,12 +54,41 @@ class CodeStyleChecker(BaseChecker):
             "both can be combined by using an assignment expression ``:=``. "
             "Requires Python 3.8 and ``py-version >= 3.8``.",
         ),
+        "R6104": (
+            "Use '%s' to do an augmented assign directly",
+            "consider-using-augmented-assign",
+            "Emitted when an assignment is referring to the object that it is assigning "
+            "to. This can be changed to be an augmented assign.\n"
+            "Disabled by default!",
+            {
+                "default_enabled": False,
+            },
+        ),
+        "R6105": (
+            "Prefer 'typing.NamedTuple' over 'collections.namedtuple'",
+            "prefer-typing-namedtuple",
+            "'typing.NamedTuple' uses the well-known 'class' keyword "
+            "with type-hints for readability (it's also faster as it avoids "
+            "an internal exec call).\n"
+            "Disabled by default!",
+            {
+                "default_enabled": False,
+            },
+        ),
+        "R6106": (
+            "Consider %smath.%s instead of %s",
+            "consider-math-not-float",
+            "Using math.inf or math.nan permits to benefit from typing and it is up "
+            "to 4 times faster than a float call (after the initial import of math). "
+            "This check also catches typos in float calls as a side effect.",
+        ),
     }
     options = (
         (
             "max-line-length-suggestions",
             {
                 "type": "int",
+                "default": 0,
                 "metavar": "<int>",
                 "help": (
                     "Max line length for which to sill emit suggestions. "
@@ -78,33 +100,67 @@ class CodeStyleChecker(BaseChecker):
         ),
     )
 
-    def __init__(self, linter: "PyLinter") -> None:
-        """Initialize checker instance."""
-        super().__init__(linter=linter)
-
     def open(self) -> None:
-        py_version = get_global_option(self, "py-version")
+        py_version = self.linter.config.py_version
+        self._py36_plus = py_version >= (3, 6)
         self._py38_plus = py_version >= (3, 8)
         self._max_length: int = (
-            self.config.max_line_length_suggestions
-            or get_global_option(self, "max-line-length")
+            self.linter.config.max_line_length_suggestions
+            or self.linter.config.max_line_length
         )
 
-    @check_messages("consider-using-namedtuple-or-dataclass")
+    @only_required_for_messages("prefer-typing-namedtuple", "consider-math-not-float")
+    def visit_call(self, node: nodes.Call) -> None:
+        if self._py36_plus:
+            called = safe_infer(node.func)
+            if not (called and isinstance(called, (nodes.FunctionDef, nodes.ClassDef))):
+                return
+            if called.qname() == "collections.namedtuple":
+                self.add_message(
+                    "prefer-typing-namedtuple", node=node, confidence=INFERENCE
+                )
+            elif called.qname() == "builtins.float":
+                if (
+                    node.args
+                    and isinstance(node.args[0], nodes.Const)
+                    and isinstance(node.args[0].value, str)
+                    and any(
+                        c.isalpha() and c.lower() != "e" for c in node.args[0].value
+                    )
+                ):
+                    value = node.args[0].value.lower()
+                    math_call: str
+                    if "nan" in value:
+                        math_call = "nan"
+                    elif "inf" in value:
+                        math_call = "inf"
+                    else:
+                        math_call = difflib.get_close_matches(
+                            value, ["inf", "nan"], n=1, cutoff=0
+                        )[0]
+                    minus = "-" if math_call == "inf" and value.startswith("-") else ""
+                    self.add_message(
+                        "consider-math-not-float",
+                        node=node,
+                        args=(minus, math_call, node.as_string()),
+                        confidence=INFERENCE,
+                    )
+
+    @only_required_for_messages("consider-using-namedtuple-or-dataclass")
     def visit_dict(self, node: nodes.Dict) -> None:
         self._check_dict_consider_namedtuple_dataclass(node)
 
-    @check_messages("consider-using-tuple")
+    @only_required_for_messages("consider-using-tuple")
     def visit_for(self, node: nodes.For) -> None:
         if isinstance(node.iter, nodes.List):
             self.add_message("consider-using-tuple", node=node.iter)
 
-    @check_messages("consider-using-tuple")
+    @only_required_for_messages("consider-using-tuple")
     def visit_comprehension(self, node: nodes.Comprehension) -> None:
         if isinstance(node.iter, nodes.List):
             self.add_message("consider-using-tuple", node=node.iter)
 
-    @check_messages("consider-using-assignment-expr")
+    @only_required_for_messages("consider-using-assignment-expr")
     def visit_if(self, node: nodes.If) -> None:
         if self._py38_plus:
             self._check_consider_using_assignment_expr(node)
@@ -112,11 +168,15 @@ class CodeStyleChecker(BaseChecker):
     def _check_dict_consider_namedtuple_dataclass(self, node: nodes.Dict) -> None:
         """Check if dictionary values can be replaced by Namedtuple or Dataclass."""
         if not (
-            isinstance(node.parent, (nodes.Assign, nodes.AnnAssign))
-            and isinstance(node.parent.parent, nodes.Module)
-            or isinstance(node.parent, nodes.AnnAssign)
-            and isinstance(node.parent.target, nodes.AssignName)
-            and utils.is_assign_name_annotated_with(node.parent.target, "Final")
+            (
+                isinstance(node.parent, (nodes.Assign, nodes.AnnAssign))
+                and isinstance(node.parent.parent, nodes.Module)
+            )
+            or (
+                isinstance(node.parent, nodes.AnnAssign)
+                and isinstance(node.parent.target, nodes.AssignName)
+                and utils.is_assign_name_annotated_with(node.parent.target, "Final")
+            )
         ):
             # If dict is not part of an 'Assign' or 'AnnAssign' node in
             # a module context OR 'AnnAssign' with 'Final' annotation, skip check.
@@ -126,10 +186,10 @@ class CodeStyleChecker(BaseChecker):
         if len(node.items) > 1 and all(
             isinstance(dict_value, nodes.Dict) for _, dict_value in node.items
         ):
-            KeyTupleT = Tuple[Type[nodes.NodeNG], str]
+            KeyTupleT = tuple[type[nodes.NodeNG], str]
 
             # Makes sure all keys are 'Const' string nodes
-            keys_checked: Set[KeyTupleT] = set()
+            keys_checked: set[KeyTupleT] = set()
             for _, dict_value in node.items:
                 dict_value = cast(nodes.Dict, dict_value)
                 for key, _ in dict_value.items:
@@ -145,13 +205,13 @@ class CodeStyleChecker(BaseChecker):
                     keys_checked.add(key_tuple)
 
             # Makes sure all subdicts have at least 1 common key
-            key_tuples: List[Tuple[KeyTupleT, ...]] = []
+            key_tuples: list[tuple[KeyTupleT, ...]] = []
             for _, dict_value in node.items:
                 dict_value = cast(nodes.Dict, dict_value)
                 key_tuples.append(
                     tuple((type(key), key.as_string()) for key, _ in dict_value.items)
                 )
-            keys_intersection: Set[KeyTupleT] = set(key_tuples[0])
+            keys_intersection: set[KeyTupleT] = set(key_tuples[0])
             for sub_key_tuples in key_tuples[1:]:
                 keys_intersection.intersection_update(sub_key_tuples)
             if not keys_intersection:
@@ -170,13 +230,11 @@ class CodeStyleChecker(BaseChecker):
             if list_length == 0:
                 return
             for _, dict_value in node.items[1:]:
-                dict_value = cast(Union[nodes.List, nodes.Tuple], dict_value)
                 if len(dict_value.elts) != list_length:
                     return
 
             # Make sure at least one list entry isn't a dict
             for _, dict_value in node.items:
-                dict_value = cast(Union[nodes.List, nodes.Tuple], dict_value)
                 if all(isinstance(entry, nodes.Dict) for entry in dict_value.elts):
                     return
 
@@ -198,23 +256,15 @@ class CodeStyleChecker(BaseChecker):
         Note: Assignment expressions were added in Python 3.8
         """
         # Check if `node.test` contains a `Name` node
-        node_name: Optional[nodes.Name] = None
-        if isinstance(node.test, nodes.Name):
-            node_name = node.test
-        elif (
-            isinstance(node.test, nodes.UnaryOp)
-            and node.test.op == "not"
-            and isinstance(node.test.operand, nodes.Name)
-        ):
-            node_name = node.test.operand
-        elif (
-            isinstance(node.test, nodes.Compare)
-            and isinstance(node.test.left, nodes.Name)
-            and len(node.test.ops) == 1
-        ):
-            node_name = node.test.left
-        else:
-            return
+        match node.test:
+            case (
+                (nodes.Name() as node_name)
+                | nodes.UnaryOp(op="not", operand=nodes.Name() as node_name)
+                | nodes.Compare(left=nodes.Name() as node_name, ops=[_])
+            ):
+                pass
+            case _:
+                return
 
         # Make sure the previous node is an assignment to the same name
         # used in `node.test`. Furthermore, ignore if assignment spans multiple lines.
@@ -222,7 +272,6 @@ class CodeStyleChecker(BaseChecker):
         if CodeStyleChecker._check_prev_sibling_to_if_stmt(
             prev_sibling, node_name.name
         ):
-
             # Check if match statement would be a better fit.
             # I.e. multiple ifs that test the same name.
             if CodeStyleChecker._check_ignore_assignment_expr_suggestion(
@@ -241,8 +290,7 @@ class CodeStyleChecker(BaseChecker):
             if (
                 node.col_offset is not None
                 and len(suggestion) + node.col_offset > self._max_length
-                or len(suggestion) > self._max_length
-            ):
+            ) or len(suggestion) > self._max_length:
                 return
 
             self.add_message(
@@ -253,8 +301,8 @@ class CodeStyleChecker(BaseChecker):
 
     @staticmethod
     def _check_prev_sibling_to_if_stmt(
-        prev_sibling: Optional[nodes.NodeNG], name: Optional[str]
-    ) -> TypeGuard[Union[nodes.Assign, nodes.AnnAssign]]:
+        prev_sibling: nodes.NodeNG | None, name: str | None
+    ) -> TypeGuard[nodes.Assign | nodes.AnnAssign]:
         """Check if previous sibling is an assignment with the same name.
 
         Ignore statements which span multiple lines.
@@ -262,24 +310,16 @@ class CodeStyleChecker(BaseChecker):
         if prev_sibling is None or prev_sibling.tolineno - prev_sibling.fromlineno != 0:
             return False
 
-        if (
-            isinstance(prev_sibling, nodes.Assign)
-            and len(prev_sibling.targets) == 1
-            and isinstance(prev_sibling.targets[0], nodes.AssignName)
-            and prev_sibling.targets[0].name == name
-        ):
-            return True
-        if (
-            isinstance(prev_sibling, nodes.AnnAssign)
-            and isinstance(prev_sibling.target, nodes.AssignName)
-            and prev_sibling.target.name == name
-        ):
-            return True
+        match prev_sibling:
+            case nodes.Assign(
+                targets=[nodes.AssignName(name=target_name)]
+            ) | nodes.AnnAssign(target=nodes.AssignName(name=target_name)):
+                return target_name == name and prev_sibling.value is not None
         return False
 
     @staticmethod
     def _check_ignore_assignment_expr_suggestion(
-        node: nodes.If, name: Optional[str]
+        node: nodes.If, name: str | None
     ) -> bool:
         """Return True if suggestion for assignment expr should be ignored.
 
@@ -287,7 +327,7 @@ class CodeStyleChecker(BaseChecker):
         (multiple conditions).
         """
         if isinstance(node.test, nodes.Compare):
-            next_if_node: Optional[nodes.If] = None
+            next_if_node: nodes.If | None = None
             next_sibling = node.next_sibling()
             if len(node.orelse) == 1 and isinstance(node.orelse[0], nodes.If):
                 # elif block
@@ -296,19 +336,26 @@ class CodeStyleChecker(BaseChecker):
                 # separate if block
                 next_if_node = next_sibling
 
-            if (  # pylint: disable=too-many-boolean-expressions
-                next_if_node is not None
-                and (
-                    isinstance(next_if_node.test, nodes.Compare)
-                    and isinstance(next_if_node.test.left, nodes.Name)
-                    and next_if_node.test.left.name == name
-                    or isinstance(next_if_node.test, nodes.Name)
-                    and next_if_node.test.name == name
-                )
-            ):
-                return True
+            match next_if_node:
+                case nodes.If(
+                    test=nodes.Compare(left=nodes.Name(name=n)) | nodes.Name(name=n)
+                ) if (n == name):
+                    return True
         return False
 
+    @only_required_for_messages("consider-using-augmented-assign")
+    def visit_assign(self, node: nodes.Assign) -> None:
+        is_aug, op = utils.is_augmented_assign(node)
+        if is_aug:
+            self.add_message(
+                "consider-using-augmented-assign",
+                args=f"{op}=",
+                node=node,
+                line=node.lineno,
+                col_offset=node.col_offset,
+                confidence=INFERENCE,
+            )
 
-def register(linter: "PyLinter") -> None:
+
+def register(linter: PyLinter) -> None:
     linter.register_checker(CodeStyleChecker(linter))
