@@ -1,6 +1,6 @@
 """https://github.com/pylint-dev/pylint/issues/4265"""
 
 try:
-    f = open('test', encoding="utf-8")
+    F = open('test', encoding="utf-8")
 except Exception:
     pass
