@@ -1,5 +1,5 @@
 # pylint: disable=missing-module-docstring
 
-dictionary = {'0': 0}
+DICTIONARY = {'0': 0}
 # quotes are inconsistent when targeting Python 3.12 (use single quotes)
-F_STRING = f'{dictionary["0"]}'  # [inconsistent-quotes]
+F_STRING = f'{DICTIONARY["0"]}'  # [inconsistent-quotes]
