@@ -138,9 +138,11 @@ def _private_scope_function_with_long_descriptive_name():
     return 12
 
 LONG_CONSTANT_NAME_IN_PUBLIC_SCOPE_ARE_OKAY = True
-# We don't emit for non-const nodes
 good_name_for_funcs = lambda: None
+BAD_NAME_FOR_FUNCS = lambda: None  # [invalid-name]
+# Non-consts can pass either the variable or const regexes at module-level.
 good_name_for_lists = [1, 2, 3]
+ALSO_GOOD_FOR_LISTS = [1, 2, 3]
 
 class _AnExceptionalExceptionThatOccursVeryVeryRarely(Exception):
     """A very exceptional exception with a nice descriptive name"""
