@@ -1,6 +1,6 @@
 """Check that we do not crash with a recursion error
 
-https://github.com/PyCQA/pylint/issues/3159
+https://github.com/pylint-dev/pylint/issues/3159
 """
 # pylint: disable=missing-docstring
 from setuptools import Command, find_packages, setup
@@ -13,8 +13,7 @@ class AnyCommand(Command):
     def finalize_options(self):
         pass
 
-    @staticmethod
-    def run():
+    def run(self):
         print("Do anything")
 
 
