@@ -1,8 +1,8 @@
 # pylint: disable=missing-docstring
-# https://github.com/PyCQA/pylint/issues/4221
+# https://github.com/pylint-dev/pylint/issues/4221
 
 import random
-o = object()
+O = object()
 if random.choice([True, False]):
-    o.count = None
+    O.count = None
 "abc".count("a")
