@@ -17,3 +17,8 @@ def main(param):
     if param == 0:
         tmp = add
     return tmp(1, 1.01)
+
+
+# Negative case, see `_check_isinstance_args` in `./pylint/checkers/typecheck.py`
+isinstance(1, int, int) # [too-many-function-args]
+isinstance(1, 1, int) # [too-many-function-args, isinstance-second-argument-not-valid-type]
